@@ -363,9 +363,10 @@ Labels [Default = no label]:
 
 Other:
     move_cur : move the cursor after drawing. Default=True.
-    color    : matplotlib color for element. e.g. 'red', '#34a4e6', (.8,0,.8)
+    color    : matplotlib color for element lines. e.g. 'red', '#34a4e6', (.8,0,.8)
     ls       : line style. same as matplotlib: ['-', ':', '--']
     lw       : line width. same as matplotlib. Default=1
+    fill     : matplotlib color for fill
     """
         # Flatten element def with base elements
         self.defn = elm_def.copy()
@@ -378,6 +379,7 @@ Other:
         self.color = kwargs.get('color', self.defn.get('color', drawing.color))
         self.ls = kwargs.get('ls', self.defn.get('ls', '-'))
         self.lw = kwargs.get('lw', self.defn.get('lw', drawing.lw))
+        self.fill = kwargs.get('fill', None)
         totlen = kwargs.get('l', drawing.unit)
 
         # Determine theta angle of element
@@ -486,12 +488,15 @@ Other:
             botlabel = kwargs.get('botlabel', None)
             rgtlabel = kwargs.get('rgtlabel', None)
             lftlabel = kwargs.get('lftlabel', None)
+            size = kwargs.get('lblsize', drawing.fontsize)
+            clabel = kwargs.get('clabel', None)
             self.lbl_ofst = kwargs.get('lblofst', self.defn.get('lblofst', drawing.txtofst))
-            if label is not None:    self.add_label(label, dfltlbl,  ofst=self.lbl_ofst, size=drawing.fontsize)
-            if toplabel is not None: self.add_label(toplabel, 'top', ofst=self.lbl_ofst, size=drawing.fontsize)
-            if botlabel is not None: self.add_label(botlabel, 'bot', ofst=self.lbl_ofst, size=drawing.fontsize)
-            if rgtlabel is not None: self.add_label(rgtlabel, 'rgt', ofst=self.lbl_ofst, size=drawing.fontsize)
-            if lftlabel is not None: self.add_label(lftlabel, 'lft', ofst=self.lbl_ofst, size=drawing.fontsize)
+            if label is not None:    self.add_label(label, dfltlbl,  ofst=self.lbl_ofst, size=size)
+            if toplabel is not None: self.add_label(toplabel, 'top', ofst=self.lbl_ofst, size=size)
+            if botlabel is not None: self.add_label(botlabel, 'bot', ofst=self.lbl_ofst, size=size)
+            if rgtlabel is not None: self.add_label(rgtlabel, 'rgt', ofst=self.lbl_ofst, size=size)
+            if lftlabel is not None: self.add_label(lftlabel, 'lft', ofst=self.lbl_ofst, size=size)
+            if clabel is not None: self.add_label(clabel, 'center', ofst=[0,0], size=size)
 
         txtlist = self.defn.get('labels', [])
         for txtlbl in txtlist:
@@ -605,7 +610,6 @@ Other:
         if align is None:   # Determine best alignment for label based on angle
             th = self.theta
             # Below alignment divisions work for label on top. Rotate angle for other sides.
-
             if loc == 'lft':
                 th = th + 90
             elif loc == 'bot':
@@ -614,7 +618,9 @@ Other:
                 th = th + 270
             th = th % 360  # Normalize angle so it's positive, clockwise
 
-            if th < 22.5:         # 0 to +22 deg
+            if loc == 'center':
+                align = ('center', 'center')
+            elif th < 22.5:         # 0 to +22 deg
                 align = ('center', 'bottom')
             elif th < 22.5+45:    #22 to 67
                 align = ('right', 'bottom')
@@ -712,28 +718,37 @@ Other:
             ax        : matplotlib axis
             showframe : Draw the axis frame. Useful for debugging.
         """
+        if self.fill:
+            for i in range(len(self.paths)):
+                tlist = [(x,y) for x, y in self.paths[i]]  # Need tuples for set hashing
+                if len(tlist) != len(set(tlist)):  # duplicate points, assume closed shape
+                    ax.fill(*list(zip(*self.paths[i])), color=self.fill, zorder=0)
+        
         for path in self.paths:
             ax.plot(path[:, 0], path[:, 1], color=self.color, lw=self.lw,
                     solid_capstyle='round', ls=self.ls)
 
         for s in self.shapes:
+            if s.get('fill', False):
+                fill = True
+                fillcolor = s.get('fillcolor', self.color)
+            else:
+                fill = self.fill is not None
+                fillcolor = self.fill
+            
             if s.get('shape') == 'circle':
                 xy = np.array(s.get('center', [0, 0]))
                 xy = self.translate(xy - self.ofst)
                 rad = s.get('radius', 1) * self.z
-                fill = s.get('fill', False)
-                fillcolor = s.get('fillcolor', self.color)
                 circ = plt.Circle(xy=xy, radius=rad, ec=self.color,
-                                  fc=fillcolor, fill=fill, zorder=3, lw=self.lw)
+                                  fc=fillcolor, fill=fill, zorder=0, lw=self.lw)
                 ax.add_patch(circ)
             elif s.get('shape') == 'poly':
                 xy = np.array(s.get('xy', [[0, 0]]))
                 xy = self.translate(xy - self.ofst)
                 closed = s.get('closed', True)
-                fill = s.get('fill', False)
-                fillcolor = s.get('fillcolor', self.color)
                 poly = plt.Polygon(xy=xy, closed=closed, ec=self.color,
-                                   fc=fillcolor, fill=fill, zorder=3, lw=self.lw)
+                                   fc=fillcolor, fill=fill, zorder=0, lw=self.lw)
                 ax.add_patch(poly)
             elif s.get('shape') == 'arc':
                 xy = np.array(s.get('center', [0, 0]))
